OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Błąd w trakcie przetwarzania loga",
    "Cased by " : "Spowodowane przez",
    "Copy" : "Kopiuj",
    "Copy raw" : "Kopiuj raw",
    "Copy formatted" : "Kopiuj sformatowany",
    "No server logs" : "Brak logów serwera",
    "One or more entries are hidden by the log level filter" : "Co najmniej jeden wpis jest ukryty ze względu na aktywny filtr poziomu logów",
    "Everything is working fine" : "Wszystko pracuje prawidłowo",
    "Level" : "Poziom",
    "App" : "Aplikacja",
    "Message" : "Komunikat",
    "Time" : "Czas",
    "Log levels" : "Poziomy",
    "Log content" : "Zawiera",
    "Live update" : "Aktualizacja na żywo",
    "Download logs" : "Pobierz",
    "Logging" : "Dziennik zdarzeń",
    "Log Reader" : "Czytnik logów",
    "A log reader for Nextcloud" : "Czytnik logów dla Nextcloud",
    "Log reader for Nextcloud" : "Czytnik logów dla Nextcloud"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
